offline_first
library
Classes
And
Generate a required condition.
ConnectOfflineFirstWithRest
An annotation used to specify a class to generate code for.
OfflineFirst
Low-level field config for the OfflineFirst domain.
OfflineFirstModel
This model is constructed by data in SQLite. It hydrates from a REST endpoint.
OfflineFirstRepository <_RepositoryModel extends OfflineFirstModel >
A ModelRepository that interacts with a SqliteProvider first before using a Provider from a remote source.
OfflineFirstSerdes <_RemoteSerializeType , _SqliteSerializeType >
A class that isn't connected to the OfflineFirstRepository but is still used
by OfflineFirstModels (such as a Cash class that declares amount and currency).
OfflineFirstSerdes must extend the class in end implementation.
Or
Generate an optional condition.
Query
An interface to request data from a Provider or Repository.
Sqlite
An annotation used to specify how a field is serialized.
Heavily inspired by JsonKey
SqliteProvider
Retrieves from a Sqlite database
SqliteSerializable
An annotation used to specify a class to generate code for.
Where
WhereCondition
Lower-level control over the value of a Query#where map.
WherePhrase
Enums
Column
SQLite data types.
Compare
Specify how to evalute the value against the evaluatedField in a WhereCondition .
For size operators, a left side comparison is done.
QueryAction
How the query interacts with the provider
brick_offline_first 1.1.0