offline_first_with_rest
library
Classes
-
And
-
Generate a required condition.
-
ConnectOfflineFirstWithRest
-
An annotation used to specify a class to generate code for.
-
LimitBy
-
Construct directions for a provider to limit its results.
-
OfflineFirst
-
Low-level field config for the
OfflineFirst domain.
-
OfflineFirstModel
-
This model is constructed by data in SQLite. It hydrates from a REST endpoint.
-
OfflineFirstSerdes<_RemoteSerializeType, _SqliteSerializeType>
-
A class that isn't connected to the
OfflineFirstRepository but is still used
by OfflineFirstModels (such as a Cash class that declares amount and currency).
OfflineFirstSerdes must extend the class in end implementation.
-
OfflineFirstWithRestAdapter<_Model extends OfflineFirstWithRestModel>
-
This adapter fetches first from SqliteProvider then hydrates with RestProvider.
-
OfflineFirstWithRestModel
-
-
OfflineFirstWithRestRepository
-
Ensures the remoteProvider is a RestProvider. All requests to and
from the remoteProvider pass through a seperate SQLite queue. If the app
is unable to make contact with the remoteProvider, the queue automatically retries in
sequence until it receives a response. Please note that a response may still be an error
code such as
404 or 500. The queue is only concerned with connectivity.
-
Or
-
Generate an optional condition.
-
OrderBy
-
Construct directions for a provider to sort its results.
-
ProviderQuery<T extends Provider<Model>>
-
Specify query arguments that are exclusive to a specific
Provider.
For example, configuring a REST's POST method.
-
Query
-
An interface to request data from a
Provider or ModelRepository.
-
Rest
-
An annotation used to specify how a field is serialized for a
RestAdapter.
Heavily inspired by JsonKey
-
RestProvider
-
Retrieves from an HTTP endpoint
-
RestSerializable
-
An annotation used to specify a class to generate code for.
-
Sqlite
-
An annotation used to specify how a field is serialized.
Heavily inspired by JsonKey
-
SqliteProvider
-
Retrieves from a Sqlite database
-
SqliteSerializable
-
An annotation used to specify a class to generate code for.
-
Where
-
A condition that evaluates to
true in the Provider should return Model.
-
WhereCondition
-
Lower-level control over the value of a
Query#where map.
-
WherePhrase
-
A collection of conditions that are evaluated together.