Where constructor
A condition that evaluates to true in the Provider should return Model.
This class should be exposed by the implemented ModelRepository and not imported from
this package as repositories may choose to extend or inhibit functionality.
Implementation
const Where(
this.evaluatedField, {
this.value,
Compare? compare,
bool? isRequired,
}) : isRequired = isRequired ?? true,
compare = compare ?? Compare.exact,
conditions = null;