offline_first
library
Classes
And
Generate a required condition.
ConnectOfflineFirstWithRest
An annotation used to specify a class to generate code for.
LimitBy
Construct directions for a provider to limit its results.
OfflineFirst
Low-level field config for the OfflineFirst domain.
OfflineFirstModel
This model is constructed by data in SQLite. It hydrates from a REST endpoint.
OfflineFirstRepository <_RepositoryModel extends OfflineFirstModel >
A ModelRepository that interacts with a SqliteProvider first before using a Provider from a remote source.
OfflineFirstSerdes <_RemoteSerializeType , _SqliteSerializeType >
A class that isn't connected to the OfflineFirstRepository but is still used
by OfflineFirstModels (such as a Cash class that declares amount and currency).
OfflineFirstSerdes must extend the class in end implementation.
Or
Generate an optional condition.
OrderBy
Construct directions for a provider to sort its results.
ProviderQuery <T extends Provider<Model > >
Specify query arguments that are exclusive to a specific Provider.
For example, configuring a REST's POST method.
Query
An interface to request data from a Provider or ModelRepository.
Sqlite
An annotation used to specify how a field is serialized.
Heavily inspired by JsonKey
SqliteProvider
Retrieves from a Sqlite database
SqliteSerializable
An annotation used to specify a class to generate code for.
Where
A condition that evaluates to true in the Provider should return Model .
WhereCondition
Lower-level control over the value of a Query#where map.
WherePhrase
A collection of conditions that are evaluated together.
brick_offline_first 1.1.0